==> teamapps-core-system-model-0.8-sources.jar: org/teamapps/model/controlcenter/UdbApplicationPerspective.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbApplicationPerspective extends AbstractUdbEntity<ApplicationPerspective> implements ApplicationPerspective {
	protected static TableIndex table;
	protected static UniversalDB universalDB;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static IntegerIndex metaRestoreDate;
	protected static IntegerIndex metaRestoredBy;
	protected static SingleReferenceIndex application;
	protected static TextIndex name;
	protected static TextIndex icon;
	protected static TextIndex titleKey;
	protected static TextIndex descriptionKey;
	protected static BooleanIndex autoProvision;
	protected static BooleanIndex toolbarPerspectiveMenu;
	protected static MultiReferenceIndex managedPerspectives;

    private static void setTableIndex(TableIndex tableIndex, UniversalDB udb) {
		universalDB = udb;
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETED_BY);
		metaRestoreDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORE_DATE);
		metaRestoredBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORED_BY);
		application = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_APPLICATION);
		name = (TextIndex) tableIndex.getFieldIndex(FIELD_NAME);
		icon = (TextIndex) tableIndex.getFieldIndex(FIELD_ICON);
		titleKey = (TextIndex) tableIndex.getFieldIndex(FIELD_TITLE_KEY);
		descriptionKey = (TextIndex) tableIndex.getFieldIndex(FIELD_DESCRIPTION_KEY);
		autoProvision = (BooleanIndex) tableIndex.getFieldIndex(FIELD_AUTO_PROVISION);
		toolbarPerspectiveMenu = (BooleanIndex) tableIndex.getFieldIndex(FIELD_TOOLBAR_PERSPECTIVE_MENU);
		managedPerspectives = (MultiReferenceIndex) tableIndex.getFieldIndex(FIELD_MANAGED_PERSPECTIVES);
    }

    public static List<ApplicationPerspective> getAll() {
        return new EntityBitSetList<>(ApplicationPerspective.getBuilder(), table.getRecordBitSet());
    }

    public static List<ApplicationPerspective> getDeletedRecords() {
        return new EntityBitSetList<>(ApplicationPerspective.getBuilder(), table.getDeletedRecordsBitSet());
    }

    public static List<ApplicationPerspective> sort(List<ApplicationPerspective> list, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
    	return sort(table, list, sortFieldName, ascending, userContext, path);
    }

    public static List<ApplicationPerspective> sort(BitSet recordIds, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
        return sort(table, ApplicationPerspective.getBuilder(), recordIds, sortFieldName, ascending, userContext, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbApplicationPerspective() {
        super(table);
    }

    public UdbApplicationPerspective(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ApplicationPerspective build() {
        return new UdbApplicationPerspective();
    }

    @Override
    public ApplicationPerspective build(int id) {
        return new UdbApplicationPerspective(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ApplicationPerspective setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ApplicationPerspective setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ApplicationPerspective setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public Instant getMetaRestoreDate() {
	    return getTimestampValue(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDate(Instant value) {
	    setTimestampValue(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoreDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public long getMetaRestoreDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoredBy() {
        return getIntValue(metaRestoredBy);
	}

	@Override
	public ApplicationPerspective setMetaRestoredBy(int value) {
	    setIntValue(value, this.metaRestoredBy);
		return this;
	}

	@Override
	public Application getApplication() {
		if (isChanged(application)) {
			return (Application) getReferenceChangeValue(application);
		} else {
			int id = application.getValue(getId());
			if (id > 0) {
				return Application.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ApplicationPerspective setApplication(Application value) {
		setSingleReferenceValue(application, value, table);
		return this;
	}

	@Override
	public String getName() {
        return getTextValue(name);
	}

	@Override
	public ApplicationPerspective setName(String value) {
	    setTextValue(value, this.name);
		return this;
	}

	@Override
	public String getIcon() {
        return getTextValue(icon);
	}

	@Override
	public ApplicationPerspective setIcon(String value) {
	    setTextValue(value, this.icon);
		return this;
	}

	@Override
	public String getTitleKey() {
        return getTextValue(titleKey);
	}

	@Override
	public ApplicationPerspective setTitleKey(String value) {
	    setTextValue(value, this.titleKey);
		return this;
	}

	@Override
	public String getDescriptionKey() {
        return getTextValue(descriptionKey);
	}

	@Override
	public ApplicationPerspective setDescriptionKey(String value) {
	    setTextValue(value, this.descriptionKey);
		return this;
	}

	@Override
	public boolean getAutoProvision() {
	    return getBooleanValue(autoProvision);
	}

	@Override
	public ApplicationPerspective setAutoProvision(boolean value) {
	    setBooleanValue(value, this.autoProvision);
		return this;
	}

	@Override
	public boolean isAutoProvision() {
	    return getBooleanValue(autoProvision);
	}

	@Override
	public boolean getToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public ApplicationPerspective setToolbarPerspectiveMenu(boolean value) {
	    setBooleanValue(value, this.toolbarPerspectiveMenu);
		return this;
	}

	@Override
	public boolean isToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public List<ManagedApplicationPerspective> getManagedPerspectives() {
	    return getMultiReferenceValue(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective setManagedPerspectives(List<ManagedApplicationPerspective> value) {
		setMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public int getManagedPerspectivesCount() {
	    return getMultiReferenceValueCount(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective setManagedPerspectives(ManagedApplicationPerspective ... value) {
		setMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public BitSet getManagedPerspectivesAsBitSet() {
	    return getMultiReferenceValueAsBitSet(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective addManagedPerspectives(List<ManagedApplicationPerspective> value) {
		addMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective addManagedPerspectives(ManagedApplicationPerspective ... value) {
		addMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeManagedPerspectives(List<ManagedApplicationPerspective> value) {
		removeMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeManagedPerspectives(ManagedApplicationPerspective ... value) {
		removeMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeAllManagedPerspectives() {
		removeAllMultiReferenceValue(managedPerspectives);
		return this;
	}



    @Override
    public UdbApplicationPerspective save() {
        saveRecord(universalDB);
        return this;
    }

    @Override
    public void delete() {
        deleteRecord(universalDB);
    }

    @Override
    public void restoreDeleted() {
        restoreDeletedRecord(universalDB);
    }
}

==> teamapps-core-system-model-0.12-sources.jar: org/teamapps/model/controlcenter/UdbApplicationPerspective.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.*;
import org.teamapps.universaldb.index.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.pojo.template.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.context.*;

import java.util.*;
import java.time.*;
import java.io.*;
import java.util.concurrent.*;
import java.util.function.Supplier;


public class UdbApplicationPerspective extends AbstractUdbEntity<ApplicationPerspective> implements ApplicationPerspective {
	protected static TableIndex table;
	protected static UniversalDB universalDB;
	protected static IntegerIndex metaCreationDate;
	protected static IntegerIndex metaCreatedBy;
	protected static IntegerIndex metaModificationDate;
	protected static IntegerIndex metaModifiedBy;
	protected static IntegerIndex metaDeletionDate;
	protected static IntegerIndex metaDeletedBy;
	protected static IntegerIndex metaRestoreDate;
	protected static IntegerIndex metaRestoredBy;
	protected static SingleReferenceIndex application;
	protected static TextIndex name;
	protected static TextIndex icon;
	protected static TextIndex titleKey;
	protected static TextIndex descriptionKey;
	protected static BooleanIndex autoProvision;
	protected static BooleanIndex toolbarPerspectiveMenu;
	protected static MultiReferenceIndex managedPerspectives;

    private static void setTableIndex(TableIndex tableIndex, UniversalDB udb) {
		universalDB = udb;
        table = tableIndex;
		metaCreationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATION_DATE);
		metaCreatedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_CREATED_BY);
		metaModificationDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFICATION_DATE);
		metaModifiedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_MODIFIED_BY);
		metaDeletionDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETION_DATE);
		metaDeletedBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_DELETED_BY);
		metaRestoreDate = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORE_DATE);
		metaRestoredBy = (IntegerIndex) tableIndex.getFieldIndex(FIELD_META_RESTORED_BY);
		application = (SingleReferenceIndex) tableIndex.getFieldIndex(FIELD_APPLICATION);
		name = (TextIndex) tableIndex.getFieldIndex(FIELD_NAME);
		icon = (TextIndex) tableIndex.getFieldIndex(FIELD_ICON);
		titleKey = (TextIndex) tableIndex.getFieldIndex(FIELD_TITLE_KEY);
		descriptionKey = (TextIndex) tableIndex.getFieldIndex(FIELD_DESCRIPTION_KEY);
		autoProvision = (BooleanIndex) tableIndex.getFieldIndex(FIELD_AUTO_PROVISION);
		toolbarPerspectiveMenu = (BooleanIndex) tableIndex.getFieldIndex(FIELD_TOOLBAR_PERSPECTIVE_MENU);
		managedPerspectives = (MultiReferenceIndex) tableIndex.getFieldIndex(FIELD_MANAGED_PERSPECTIVES);
    }

    public static List<ApplicationPerspective> getAll() {
        return new EntityBitSetList<>(ApplicationPerspective.getBuilder(), table.getRecordBitSet());
    }

    public static List<ApplicationPerspective> getDeletedRecords() {
        return new EntityBitSetList<>(ApplicationPerspective.getBuilder(), table.getDeletedRecordsBitSet());
    }

    public static List<ApplicationPerspective> sort(List<ApplicationPerspective> list, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
    	return sort(table, list, sortFieldName, ascending, userContext, path);
    }

    public static List<ApplicationPerspective> sort(BitSet recordIds, String sortFieldName, boolean ascending, UserContext userContext, String ... path) {
        return sort(table, ApplicationPerspective.getBuilder(), recordIds, sortFieldName, ascending, userContext, path);
    }

    public static int getCount() {
        return table.getCount();
    }

    public UdbApplicationPerspective() {
        super(table);
    }

    public UdbApplicationPerspective(int id, boolean createEntity) {
        super(table, id, createEntity);
    }

    @Override
    public ApplicationPerspective build() {
        return new UdbApplicationPerspective();
    }

    @Override
    public ApplicationPerspective build(int id) {
        return new UdbApplicationPerspective(id, false);
    }

	@Override
	public Instant getMetaCreationDate() {
	    return getTimestampValue(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDate(Instant value) {
	    setTimestampValue(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaCreationDate);
		return this;
	}

	@Override
	public long getMetaCreationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaCreationDate);
	}

	@Override
	public ApplicationPerspective setMetaCreationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaCreationDate);
		return this;
	}

	@Override
	public int getMetaCreatedBy() {
        return getIntValue(metaCreatedBy);
	}

	@Override
	public ApplicationPerspective setMetaCreatedBy(int value) {
	    setIntValue(value, this.metaCreatedBy);
		return this;
	}

	@Override
	public Instant getMetaModificationDate() {
	    return getTimestampValue(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDate(Instant value) {
	    setTimestampValue(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModificationDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaModificationDate);
		return this;
	}

	@Override
	public long getMetaModificationDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaModificationDate);
	}

	@Override
	public ApplicationPerspective setMetaModificationDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaModificationDate);
		return this;
	}

	@Override
	public int getMetaModifiedBy() {
        return getIntValue(metaModifiedBy);
	}

	@Override
	public ApplicationPerspective setMetaModifiedBy(int value) {
	    setIntValue(value, this.metaModifiedBy);
		return this;
	}

	@Override
	public Instant getMetaDeletionDate() {
	    return getTimestampValue(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDate(Instant value) {
	    setTimestampValue(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletionDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public long getMetaDeletionDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaDeletionDate);
	}

	@Override
	public ApplicationPerspective setMetaDeletionDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaDeletionDate);
		return this;
	}

	@Override
	public int getMetaDeletedBy() {
        return getIntValue(metaDeletedBy);
	}

	@Override
	public ApplicationPerspective setMetaDeletedBy(int value) {
	    setIntValue(value, this.metaDeletedBy);
		return this;
	}

	@Override
	public Instant getMetaRestoreDate() {
	    return getTimestampValue(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDate(Instant value) {
	    setTimestampValue(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoreDateAsEpochSecond() {
	    return getTimestampAsEpochSecond(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDateAsEpochSecond(int value) {
	    setTimestampAsEpochSecond(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public long getMetaRestoreDateAsEpochMilli() {
	    return getTimestampAsEpochMilli(metaRestoreDate);
	}

	@Override
	public ApplicationPerspective setMetaRestoreDateAsEpochMilli(long value) {
	    setTimestampAsEpochMilli(value, this.metaRestoreDate);
		return this;
	}

	@Override
	public int getMetaRestoredBy() {
        return getIntValue(metaRestoredBy);
	}

	@Override
	public ApplicationPerspective setMetaRestoredBy(int value) {
	    setIntValue(value, this.metaRestoredBy);
		return this;
	}

	@Override
	public Application getApplication() {
		if (isChanged(application)) {
			return (Application) getReferenceChangeValue(application);
		} else {
			int id = application.getValue(getId());
			if (id > 0) {
				return Application.getById(id);
			} else {
				return null;
			}
		}
	}

	@Override
	public ApplicationPerspective setApplication(Application value) {
		setSingleReferenceValue(application, value, table);
		return this;
	}

	@Override
	public String getName() {
        return getTextValue(name);
	}

	@Override
	public ApplicationPerspective setName(String value) {
	    setTextValue(value, this.name);
		return this;
	}

	@Override
	public String getIcon() {
        return getTextValue(icon);
	}

	@Override
	public ApplicationPerspective setIcon(String value) {
	    setTextValue(value, this.icon);
		return this;
	}

	@Override
	public String getTitleKey() {
        return getTextValue(titleKey);
	}

	@Override
	public ApplicationPerspective setTitleKey(String value) {
	    setTextValue(value, this.titleKey);
		return this;
	}

	@Override
	public String getDescriptionKey() {
        return getTextValue(descriptionKey);
	}

	@Override
	public ApplicationPerspective setDescriptionKey(String value) {
	    setTextValue(value, this.descriptionKey);
		return this;
	}

	@Override
	public boolean getAutoProvision() {
	    return getBooleanValue(autoProvision);
	}

	@Override
	public ApplicationPerspective setAutoProvision(boolean value) {
	    setBooleanValue(value, this.autoProvision);
		return this;
	}

	@Override
	public boolean isAutoProvision() {
	    return getBooleanValue(autoProvision);
	}

	@Override
	public boolean getToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public ApplicationPerspective setToolbarPerspectiveMenu(boolean value) {
	    setBooleanValue(value, this.toolbarPerspectiveMenu);
		return this;
	}

	@Override
	public boolean isToolbarPerspectiveMenu() {
	    return getBooleanValue(toolbarPerspectiveMenu);
	}

	@Override
	public List<ManagedApplicationPerspective> getManagedPerspectives() {
	    return getMultiReferenceValue(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective setManagedPerspectives(List<ManagedApplicationPerspective> value) {
		setMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public int getManagedPerspectivesCount() {
	    return getMultiReferenceValueCount(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective setManagedPerspectives(ManagedApplicationPerspective ... value) {
		setMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public BitSet getManagedPerspectivesAsBitSet() {
	    return getMultiReferenceValueAsBitSet(managedPerspectives, ManagedApplicationPerspective.getBuilder());
	}

	@Override
	public ApplicationPerspective addManagedPerspectives(List<ManagedApplicationPerspective> value) {
		addMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective addManagedPerspectives(ManagedApplicationPerspective ... value) {
		addMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeManagedPerspectives(List<ManagedApplicationPerspective> value) {
		removeMultiReferenceValue(value, managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeManagedPerspectives(ManagedApplicationPerspective ... value) {
		removeMultiReferenceValue(Arrays.asList(value), managedPerspectives);
		return this;
	}

	@Override
	public ApplicationPerspective removeAllManagedPerspectives() {
		removeAllMultiReferenceValue(managedPerspectives);
		return this;
	}



    @Override
    public UdbApplicationPerspective save() {
        saveRecord(universalDB);
        return this;
    }

   @Override
    public UdbApplicationPerspective save(int userId, long timestamp) {
        saveRecord(universalDB, userId, timestamp);
        return this;
    }

    @Override
    public void delete() {
        deleteRecord(universalDB);
    }

    @Override
    public void delete(int userId, long timestamp) {
        deleteRecord(universalDB, userId, timestamp);
    }

    @Override
    public void restoreDeleted() {
        restoreDeletedRecord(universalDB);
    }

    @Override
    public void restoreDeleted(int userId, long timestamp) {
        restoreDeletedRecord(universalDB, userId, timestamp);
    }
}
